@@ -77,7 +77,7 @@ NULL
       if (chol) .ret[.i, .j] <- 0
     }
   }
-  if (chol){
+  if (chol) {
     .ret <- .ret %*% t(.ret)
     return(.ret)
   }
@@ -162,8 +162,15 @@ NULL
   .num <- as.numeric(eval(.repFixedWithC(x, .env), envir=.lotriParentEnv))
   return(list(.num, .env$fix, .env$unfix))
 }
-
-.lotriParseMat <- function(x, env=NULL) {
+#' Assert the proper properties of a lotri matrix (cant mix var, sd ) etc
+#'
+#' 
+#' @param x expression
+#' @param env environment
+#' @return Nothing called for side effects
+#' @author Matthew L. Fidler
+#' @noRd
+.lotriParseMatAssertGoodProps <- function(x, env=NULL) {
   if (identical(x[[1]], quote(`sd`))) {
     if (exists("var", envir=env)) {
       stop("cannot use both 'var' and 'sd' in a block", call.=FALSE)
@@ -197,6 +204,15 @@ NULL
     }
     env$chol <- TRUE
   }
+}
+#' Calculate fixed properties
+#' 
+#' @param x expression 
+#' @param env environment
+#' @return nothing called for side effects
+#' @author Matthew L. Fidler
+#' @noRd
+.lotriParseMatCalculateFixedProps <- function(x, env=NULL) {
   if (identical(x[[1]], quote(`fix`)) ||
         identical(x[[1]], quote(`fixed`)) ||
         identical(x[[1]], quote(`FIX`)) ||
@@ -209,6 +225,11 @@ NULL
         identical(x[[1]], quote(`UNFIX`))) {
     env$globalUnfix <- TRUE
   }
+}
+
+.lotriParseMat <- function(x, env=NULL) {
+  .lotriParseMatAssertGoodProps(x, env)
+  .lotriParseMatCalculateFixedProps(x, env)
   if (length(x) == 2) {
     return(.lotriParseMat(x[[2]], env=env))
   } else if (length(x) == 1) {
@@ -232,10 +253,12 @@ NULL
   if (!exists("globalUnfix", env)) {
     env$globalUnfix <- FALSE
   }
-  .fix <- vapply(env$fix, function(x){ifelse(is.na(x), env$globalFix, x)},
-                 logical(1))
-  .unfix <- vapply(env$unfix, function(x){ifelse(is.na(x), env$globalUnfix, x)},
-                   logical(1))
+  .fix <- vapply(env$fix, function(x) {
+    ifelse(is.na(x), env$globalFix, x)
+  }, logical(1))
+  .unfix <- vapply(env$unfix, function(x) {
+    ifelse(is.na(x), env$globalUnfix, x)
+  }, logical(1))
   return(list(env$nv, .fix, .unfix))
 }
 
@@ -293,6 +316,10 @@ NULL
         }
       }
       env$eta1 <- env$eta1 + .num
+    } else if (.num - length(.n) < 0) {
+      .expr <- paste(.deparse1(x2), "~", .deparse1(x3))
+      stop("number named variables and lower triangular matrix size do not match:\n",
+           .expr)
     } else {
       ## in this case
       .expr <- .deparse1(eval(parse(text=paste0("quote(", paste(c(.n, paste0("varName", length(.n) + seq_len(.num - length(.n)))), collapse="+"), "~ 0)"))))
@@ -665,7 +692,7 @@ NULL
     stop("duplicated parameter(s): '",paste(.dup, collapse="', '"), "'", sep="",
          call.=FALSE)
   }
-  if ((inherits(ret, "matrix") | inherits(ret, "list") | inherits(ret, "lotri")) &
+  if ((inherits(ret, "matrix") || inherits(ret, "list") || inherits(ret, "lotri")) &&
         !inherits(ret, "lotriFix")) {
     class(ret) <- c("lotriFix", class(ret))
   }
